==> ZenTaoPMS.15.0.2.zip: zentaopms/module/user/lang/vi.php <==
<?php
/**
 * The user module English file of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2015 青岛易软天创网络科技有限公司(QingDao Nature Easy Soft Network Technology Co,LTD, www.cnezsoft.com)
 * @license  ZPL (http://zpl.pub/page/zplv12.html)
 * @author   Nguyễn Quốc Nho <quocnho@gmail.com>
 * @package  user
 * @version  $Id: vi.php 5053 2013-07-06 08:17:37Z wyd621@gmail.com $
 * @link  http://www.zentao.net
 */
$lang->user->common           = 'Người dùng';
$lang->user->id               = 'ID';
$lang->user->inside           = 'Inside Members';
$lang->user->outside          = 'Outside Members';
$lang->user->company          = 'Doanh nghiệp';
$lang->user->dept             = 'Phòng/Ban';
$lang->user->account          = 'Tài khoản';
$lang->user->password         = 'Mật khẩu';
$lang->user->password2        = 'Nhập lại mật khẩu';
$lang->user->role             = 'Vai trò';
$lang->user->group            = 'Nhóm quyền';
$lang->user->realname         = 'Tên';
$lang->user->nickname         = 'Nickname';
$lang->user->commiter         = 'Tài khoản SVN/GIT';
$lang->user->birthyear        = 'Ngày sinh';
$lang->user->gender           = 'Giới tính';
$lang->user->email            = 'Email';
$lang->user->basicInfo        = 'Thông tin cơ bản';
$lang->user->accountInfo      = 'Thông tin tài khoản';
$lang->user->verify           = 'Xác thực';
$lang->user->contactInfo      = 'Liên hệ';
$lang->user->skype            = 'Skype';
$lang->user->qq               = 'QQ';
$lang->user->mobile           = 'Mobile';
$lang->user->phone            = 'Điện thoại';
$lang->user->weixin           = 'WeChat';
$lang->user->dingding         = 'DingDing';
$lang->user->slack            = 'Slack';
$lang->user->whatsapp         = 'WhatsApp';
$lang->user->address          = 'Địa chỉ';
$lang->user->zipcode          = 'ZipCode';
$lang->user->join             = 'Đã tham gia';
$lang->user->visits           = 'Visits';
$lang->user->ip               = 'IP gần nhất';
$lang->user->last             = 'Đăng nhập gần nhất';
$lang->user->ranzhi           = 'Tài khoản Zdoo';
$lang->user->ditto            = 'Như trên';
$lang->user->originalPassword = 'Mật khẩu cũ';
$lang->user->newPassword      = 'Mật khẩu mới';
$lang->user->verifyPassword   = 'Mật khẩu';
$lang->user->resetPassword    = 'Quên mật khẩu?';
$lang->user->score            = 'Điểm';
$lang->user->name             = 'Name';
$lang->user->type             = 'User Type';
$lang->user->cropAvatar       = 'Crop Avatar';
$lang->user->cropAvatarTip    = 'Drag and drop the box to select the image clipping range.';
$lang->user->cropImageTip     = 'The image used is too small, the recommended image size is at least 48x48, the current image size is %s';

$lang->user->legendBasic        = 'Thông tin cơ bản';
$lang->user->legendContribution = 'Đóng góp';

$lang->user->index         = "Home";
$lang->user->view          = "Chi tiết người dùng";
$lang->user->create        = "Thêm người dùng";
$lang->user->batchCreate   = "Thêm hàng loạt";
$lang->user->edit          = "Sửa người dùng";
$lang->user->batchEdit     = "Sửa hàng loạt";
$lang->user->unlock        = "Mở khóa người dùng";
$lang->user->delete        = "Xóa người dùng";
$lang->user->unbind        = "Gỡ kết nối từ Zdoo";
$lang->user->login         = "Đăng nhập";
$lang->user->bind          = "Bind User";
$lang->user->oauthRegister = "Register a new account";
$lang->user->mobileLogin   = "Di động";
$lang->user->editProfile   = "Sửa hồ sơ";
$lang->user->deny          = "Truy cập của bạn bị từ chối.";
$lang->user->confirmDelete = "Bạn có muốn xóa người dùng này?";
$lang->user->confirmUnlock = "Bạn có muốn mở khóa người dùng này?";
$lang->user->confirmUnbind = "Bạn có muốn hủy kết nối người dùng này từ Zdoo?";
$lang->user->relogin       = "Đăng nhập lại";
$lang->user->asGuest       = "Khách vãng lai";
$lang->user->goback        = "Trở lại";
$lang->user->deleted       = '(Xóa)';
$lang->user->search        = 'Tìm kiếm';
$lang->user->else          = 'Else';

$lang->user->saveTemplate          = 'Lưu thành mẫu';
$lang->user->setPublic             = 'Thiết lập thành mẫu công khai';
$lang->user->deleteTemplate        = 'Xóa mẫu';
$lang->user->setTemplateTitle      = 'Vui lòng nhập tiêu đề của mẫu.';
$lang->user->applyTemplate         = 'Mẫu';
$lang->user->confirmDeleteTemplate = 'Bạn có muốn xóa mẫu này?';
$lang->user->setPublicTemplate     = 'Thiết lập thành mẫu công khai';
$lang->user->tplContentNotEmpty    = 'Nội dung mẫu này không thể để trống!';

$lang->user->profile   = 'Hồ sơ';
$lang->user->project   = $lang->executionCommon;
$lang->user->execution = 'Execution';
$lang->user->task      = 'Nhiệm vụ';
$lang->user->bug       = 'Bugs';
$lang->user->test      = 'Test';
$lang->user->testTask  = 'Yêu cầu';
$lang->user->testCase  = 'Tình huống';
$lang->user->issue     = 'Issue';
$lang->user->risk      = 'Risk';
$lang->user->schedule  = 'Lịch trình';
$lang->user->todo      = 'Việc làm';
$lang->user->story     = 'Câu chuyện';
$lang->user->dynamic   = 'Lịch sử';

$lang->user->openedBy   = 'Đã tạo';
$lang->user->assignedTo = 'Đã nhận';
$lang->user->finishedBy = 'Đã kết thúc';
$lang->user->resolvedBy = 'Đã giải quyết';
$lang->user->closedBy   = 'Đã đóng';
$lang->user->reviewedBy = 'Đã duyệt';
$lang->user->canceledBy = 'Đã hủy';

$lang->user->testTask2Him = 'Nhận yêu cầu';
$lang->user->case2Him     = 'Nhận tình huống';
$lang->user->caseByHim    = 'Tạo tình huống';

$lang->user->errorDeny    = "Xin lỗi, truy cập của bạn tới <b>%s</b> of <b>%s</b> bị từ chối. Vui lòng liên lạc quản trị của bạn để nhận quyền. Click Trở lại.";
$lang->user->errorView    = "Xin lỗi, truy cập của bạn xem <b>%s</b> bị từ chối. Vui lòng liên lạc quản trị của bạn để nhận quyền. Click Trở lại.";
$lang->user->loginFailed  = "Đăng nhập thất bại. Vui lòng kiểm tra tài khoản và mật khẩu của bạn.";
$lang->user->lockWarning  = "Bạn có thể thử %s lần.";
$lang->user->loginLocked  = "Vui lòng liên hệ với quản trị viên để mở khóa tài khoản của bạn hoặc thử lại %s phút sau.";
$lang->user->weakPassword = "Mật khẩu của bạn không đúng yêu cầu.";
$lang->user->errorWeak    = "Mật khẩu không thể sử dụng [%s] những ký tự chung này được dùng mật khẩu yếu.";

$lang->user->roleList['']       = '';
$lang->user->roleList['dev']    = 'Lập trình viên';
$lang->user->roleList['qa']     = 'Tester';
$lang->user->roleList['pm']     = 'Scrum Master';
$lang->user->roleList['po']     = 'Sở hữu sản phẩm';
$lang->user->roleList['td']     = 'Quản lý kỹ thuật';
$lang->user->roleList['pd']     = 'Quản lý sản phẩm';
$lang->user->roleList['qd']     = 'Quản lý QA';
$lang->user->roleList['top']    = 'Quản lý cấp cao';
$lang->user->roleList['others'] = 'Khác';

$lang->user->genderList['m'] = 'Nam';
$lang->user->genderList['f'] = 'Nữ';

$lang->user->thirdPerson['m'] = 'anh ấy';
$lang->user->thirdPerson['f'] = 'cô ấy';

$lang->user->typeList['inside']  = $lang->user->inside;
$lang->user->typeList['outside'] = $lang->user->outside;

$lang->user->passwordStrengthList[0] = "<span style='color:red'>Yếu</span>";
$lang->user->passwordStrengthList[1] = "<span style='color:#000'>Tốt</span>";
$lang->user->passwordStrengthList[2] = "<span style='color:green'>Mạnh</span>";

$lang->user->statusList['active'] = 'Kích hoạt';
$lang->user->statusList['delete'] = 'Đã xóa';

$lang->user->personalData['createdTodos']        = 'Todos Created';
$lang->user->personalData['createdRequirements'] = "Requirements Created";
$lang->user->personalData['createdStories']      = "Stories Created";
$lang->user->personalData['finishedTasks']       = 'Tasks Finished';
$lang->user->personalData['createdBugs']         = 'Bugs Created';
$lang->user->personalData['resolvedBugs']        = 'Bugs Resolved';
$lang->user->personalData['createdCases']        = 'Cases Created';
$lang->user->personalData['createdRisks']        = 'Risks Created';
$lang->user->personalData['resolvedRisks']       = 'Risks Resolved';
$lang->user->personalData['createdIssues']       = 'Issues Created';
$lang->user->personalData['resolvedIssues']      = 'Issues Resolved';
$lang->user->personalData['createdDocs']         = 'Docs Created';

$lang->user->keepLogin['on']   = 'Duy trì đăng nhập';
$lang->user->loginWithDemoUser = 'Đăng nhập Demo:';

$lang->user->tpl = new stdclass();
$lang->user->tpl->type    = 'Loại';
$lang->user->tpl->title   = 'TPL Title';
$lang->user->tpl->content = 'Nội dung';
$lang->user->tpl->public  = 'Công khai';

$lang->usertpl = new stdclass();
$lang->usertpl->title = 'Tên mẫu';

$lang->user->placeholder = new stdclass();
$lang->user->placeholder->account   = '>= 3 chữ, gạch chân và số';
$lang->user->placeholder->password1 = '>= 6 chữ';
$lang->user->placeholder->role      = "Vai trò được liên kết đến nội dung và thứ tự danh sách người dùng.";
$lang->user->placeholder->group     = "Nhóm được liên kết tới phân quyền người dùng.";
$lang->user->placeholder->commiter  = 'Tài khoản SVN/Git';
$lang->user->placeholder->verify    = 'Vui lòng nhập mật khẩu đăng nhập của bạn.';

$lang->user->placeholder->passwordStrength[1] = '>= 6 chữ và số';
$lang->user->placeholder->passwordStrength[2] = '>= 10 chữ, sood và ký tự đặc biệt';

$lang->user->error = new stdclass();
$lang->user->error->account        = "ID %s，tài khoản phải >= 3 chữ, gạch chân hoặc số";
$lang->user->error->accountDupl    = "ID %s，tài khoản được sử dụng.";
$lang->user->error->realname       = "ID %s，phải là tên thật";
$lang->user->error->password       = "ID %s，mật khẩu phải >= 6 ký tự.";
$lang->user->error->mail           = "ID %s，vui lòng nhập địa chỉ Email hợp lệ";
$lang->user->error->reserved       = "ID %s，tài khoản được bảo mật.";
$lang->user->error->weakPassword   = "ID %s，độ mạnh mật khẩu này yếu hơn thiết lập hệ thống.";
$lang->user->error->dangerPassword = "ID %s，Mật khẩu không thể được dùng với [%s] những điều chung này được dùng nếu mật khẩu..";

$lang->user->error->verifyPassword   = "Xác thực thất bại. Vui lòng nhập mạt khẩu đăng nhập của bạn.";
$lang->user->error->originalPassword = "Old password is incorrect.";
$lang->user->error->noAccess         = "This user is not from your department. You have no access to this user information.";

$lang->user->contactFieldList['phone']    = $lang->user->phone;
$lang->user->contactFieldList['mobile']   = $lang->user->mobile;
$lang->user->contactFieldList['qq']       = $lang->user->qq;
$lang->user->contactFieldList['dingding'] = $lang->user->dingding;
$lang->user->contactFieldList['weixin']   = $lang->user->weixin;
$lang->user->contactFieldList['skype']    = $lang->user->skype;
$lang->user->contactFieldList['slack']    = $lang->user->slack;
$lang->user->contactFieldList['whatsapp'] = $lang->user->whatsapp;

$lang->user->executionTypeList['stage']  = 'Stage';
$lang->user->executionTypeList['sprint'] = $lang->iterationCommon;

$lang->user->contacts = new stdclass();
$lang->user->contacts->common   = 'Liên lạc';
$lang->user->contacts->listName = 'Tên danh sách';
$lang->user->contacts->userList = 'Danh sách người dùng';

$lang->user->contacts->manage        = 'Quản lý danh sách';
$lang->user->contacts->contactsList  = 'Liên hệ danh sách';
$lang->user->contacts->selectedUsers = 'Người dùng';
$lang->user->contacts->selectList    = 'Danh sách';
$lang->user->contacts->createList    = 'Tạo danh sách';
$lang->user->contacts->noListYet     = 'Không có danh sách liên hệ tồn tại. Vui lòng tạo một trước.';
$lang->user->contacts->confirmDelete = 'Bạn có muốn xóa danh sách này?';
$lang->user->contacts->or            = ' or ';

$lang->user->resetFail       = "Thất bại. Vui lòng kiểm tra tài khoản.";
$lang->user->resetSuccess    = "Reset! Vui lòng sử dụng mật khẩu mới của bạn để đăng nhập.";
$lang->user->noticeResetFile = "<h5>Liên hệ quản trị viên để thiết lập lại mật khẩu của bạn.</h5>
 <h5>Nếu là bạn, vui lòng đăng nhập host ZenTao của bạn và tạo một tập tin tên  <span> '%s' </span>.</h5>
 <p>Chú ý:</p>
 <ol>
 <li>Giữ tập tin này rỗng.</li>
 <li>Nếu tập tin đã tồn tại, xóa và tạo lại.</li>
 </ol>";
$lang->user->notice4Safe = "Warning: Weak password of one click package detected";
$lang->user->process4DIR = "It is detected that you may be using the one click installation package environment. Other sites in the environment are still using simple passwords. For security reasons, if you do not use other sites, please handle them in time. Delete or rename the %s directory. Visit: <a href='https://www.zentao.pm/book/zentaomanual/fix-weak-password-564.html' target='_blank'>https://www.zentao.pm/book/zentaomanual/fix-weak-password-564.html</a>";
$lang->user->process4DB  = "It is detected that you may be using the one click installation package environment. Other sites in the environment are still using simple passwords. For security reasons, if you do not use other sites, please handle them in time. Please login database and modify password field of zt_user table of %s database. Visit: <a href='https://www.zentao.pm/book/zentaomanual/fix-weak-password-564.html' target='_blank'>https://www.zentao.pm/book/zentaomanual/fix-weak-password-564.html</a>";

==> ZenTaoPMS.15.2.zip: zentaopms/module/user/lang/vi.php <==
<?php
/**
 * The user module English file of ZenTaoPMS.
 *
 * @copyright   Copyright 2009-2015 青岛易软天创网络科技有限公司(QingDao Nature Easy Soft Network Technology Co,LTD, www.cnezsoft.com)
 * @license  ZPL (http://zpl.pub/page/zplv12.html)
 * @author   Nguyễn Quốc Nho <quocnho@gmail.com>
 * @package  user
 * @version  $Id: vi.php 5053 2013-07-06 08:17:37Z wyd621@gmail.com $
 * @link  http://www.zentao.net
 */
$lang->user->common           = 'Người dùng';
$lang->user->id               = 'ID';
$lang->user->inside           = 'Inside Members';
$lang->user->outside          = 'Outside Members';
$lang->user->company          = 'Doanh nghiệp';
$lang->user->dept             = 'Phòng/Ban';
$lang->user->account          = 'Tài khoản';
$lang->user->password         = 'Mật khẩu';
$lang->user->password2        = 'Nhập lại mật khẩu';
$lang->user->role             = 'Vai trò';
$lang->user->group            = 'Nhóm quyền';
$lang->user->realname         = 'Tên';
$lang->user->nickname         = 'Nickname';
$lang->user->commiter         = 'Tài khoản SVN/GIT';
$lang->user->birthyear        = 'Ngày sinh';
$lang->user->gender           = 'Giới tính';
$lang->user->email            = 'Email';
$lang->user->basicInfo        = 'Thông tin cơ bản';
$lang->user->accountInfo      = 'Thông tin tài khoản';
$lang->user->verify           = 'Xác thực';
$lang->user->contactInfo      = 'Liên hệ';
$lang->user->skype            = 'Skype';
$lang->user->qq               = 'QQ';
$lang->user->mobile           = 'Mobile';
$lang->user->phone            = 'Điện thoại';
$lang->user->weixin           = 'WeChat';
$lang->user->dingding         = 'DingDing';
$lang->user->slack            = 'Slack';
$lang->user->whatsapp         = 'WhatsApp';
$lang->user->address          = 'Địa chỉ';
$lang->user->zipcode          = 'ZipCode';
$lang->user->join             = 'Đã tham gia';
$lang->user->visits           = 'Visits';
$lang->user->ip               = 'IP gần nhất';
$lang->user->last             = 'Đăng nhập gần nhất';
$lang->user->ranzhi           = 'Tài khoản Zdoo';
$lang->user->ditto            = 'Như trên';
$lang->user->originalPassword = 'Mật khẩu cũ';
$lang->user->newPassword      = 'Mật khẩu mới';
$lang->user->verifyPassword   = 'Mật khẩu';
$lang->user->resetPassword    = 'Quên mật khẩu?';
$lang->user->score            = 'Điểm';
$lang->user->name             = 'Name';
$lang->user->type             = 'User Type';
$lang->user->cropAvatar       = 'Crop Avatar';
$lang->user->cropAvatarTip    = 'Drag and drop the box to select the image clipping range.';
$lang->user->cropImageTip     = 'The image used is too small, the recommended image size is at least 48x48, the current image size is %s';

$lang->user->legendBasic        = 'Thông tin cơ bản';
$lang->user->legendContribution = 'Đóng góp';

$lang->user->index         = "Home";
$lang->user->view          = "Chi tiết người dùng";
$lang->user->create        = "Thêm người dùng";
$lang->user->batchCreate   = "Thêm hàng loạt";
$lang->user->edit          = "Sửa người dùng";
$lang->user->batchEdit     = "Sửa hàng loạt";
$lang->user->unlock        = "Mở khóa người dùng";
$lang->user->delete        = "Xóa người dùng";
$lang->user->unbind        = "Gỡ kết nối từ Zdoo";
$lang->user->login         = "Đăng nhập";
$lang->user->bind          = "Bind User";
$lang->user->oauthRegister = "Register a new account";
$lang->user->mobileLogin   = "Di động";
$lang->user->editProfile   = "Sửa hồ sơ";
$lang->user->deny          = "Truy cập của bạn bị từ chối.";
$lang->user->confirmDelete = "Bạn có muốn xóa người dùng này?";
$lang->user->confirmUnlock = "Bạn có muốn mở khóa người dùng này?";
$lang->user->confirmUnbind = "Bạn có muốn hủy kết nối người dùng này từ Zdoo?";
$lang->user->relogin       = "Đăng nhập lại";
$lang->user->asGuest       = "Khách vãng lai";
$lang->user->goback        = "Trở lại";
$lang->user->deleted       = '(Xóa)';
$lang->user->search        = 'Tìm kiếm';
$lang->user->else          = 'Else';

$lang->user->saveTemplate          = 'Lưu thành mẫu';
$lang->user->setPublic             = 'Thiết lập thành mẫu công khai';
$lang->user->deleteTemplate        = 'Xóa mẫu';
$lang->user->setTemplateTitle      = 'Vui lòng nhập tiêu đề của mẫu.';
$lang->user->applyTemplate         = 'Mẫu';
$lang->user->confirmDeleteTemplate = 'Bạn có muốn xóa mẫu này?';
$lang->user->setPublicTemplate     = 'Thiết lập thành mẫu công khai';
$lang->user->tplContentNotEmpty    = 'Nội dung mẫu này không thể để trống!';

$lang->user->profile   = 'Hồ sơ';
$lang->user->project   = $lang->executionCommon;
$lang->user->execution = 'Execution';
$lang->user->task      = 'Nhiệm vụ';
$lang->user->bug       = 'Bugs';
$lang->user->test      = 'Test';
$lang->user->testTask  = 'Yêu cầu';
$lang->user->testCase  = 'Tình huống';
$lang->user->issue     = 'Issue';
$lang->user->risk      = 'Risk';
$lang->user->schedule  = 'Lịch trình';
$lang->user->todo      = 'Việc làm';
$lang->user->story     = 'Câu chuyện';
$lang->user->dynamic   = 'Lịch sử';

$lang->user->openedBy   = 'Đã tạo';
$lang->user->assignedTo = 'Đã nhận';
$lang->user->finishedBy = 'Đã kết thúc';
$lang->user->resolvedBy = 'Đã giải quyết';
$lang->user->closedBy   = 'Đã đóng';
$lang->user->reviewedBy = 'Đã duyệt';
$lang->user->canceledBy = 'Đã hủy';

$lang->user->testTask2Him = 'Nhận yêu cầu';
$lang->user->case2Him     = 'Nhận tình huống';
$lang->user->caseByHim    = 'Tạo tình huống';

$lang->user->errorDeny    = "Sorry, your access to <b>%s</b> of <b>%s</b> is denied. Please contact your Admin to get privileges. Return to home page or login again.";
$lang->user->errorView    = "Sorry, your access view <b>%s</b> is denied. Please contact your Admin to get privileges. Return to home page or login again.";
$lang->user->loginFailed  = "Đăng nhập thất bại. Vui lòng kiểm tra tài khoản và mật khẩu của bạn.";
$lang->user->lockWarning  = "Bạn có thể thử %s lần.";
$lang->user->loginLocked  = "Vui lòng liên hệ với quản trị viên để mở khóa tài khoản của bạn hoặc thử lại %s phút sau.";
$lang->user->weakPassword = "Mật khẩu của bạn không đúng yêu cầu.";
$lang->user->errorWeak    = "Mật khẩu không thể sử dụng [%s] những ký tự chung này được dùng mật khẩu yếu.";

$lang->user->roleList['']       = '';
$lang->user->roleList['dev']    = 'Lập trình viên';
$lang->user->roleList['qa']     = 'Tester';
$lang->user->roleList['pm']     = 'Scrum Master';
$lang->user->roleList['po']     = 'Sở hữu sản phẩm';
$lang->user->roleList['td']     = 'Quản lý kỹ thuật';
$lang->user->roleList['pd']     = 'Quản lý sản phẩm';
$lang->user->roleList['qd']     = 'Quản lý QA';
$lang->user->roleList['top']    = 'Quản lý cấp cao';
$lang->user->roleList['others'] = 'Khác';

$lang->user->genderList['m'] = 'Nam';
$lang->user->genderList['f'] = 'Nữ';

$lang->user->thirdPerson['m'] = 'anh ấy';
$lang->user->thirdPerson['f'] = 'cô ấy';

$lang->user->typeList['inside']  = $lang->user->inside;
$lang->user->typeList['outside'] = $lang->user->outside;

$lang->user->passwordStrengthList[0] = "<span style='color:red'>Yếu</span>";
$lang->user->passwordStrengthList[1] = "<span style='color:#000'>Tốt</span>";
$lang->user->passwordStrengthList[2] = "<span style='color:green'>Mạnh</span>";

$lang->user->statusList['active'] = 'Kích hoạt';
$lang->user->statusList['delete'] = 'Đã xóa';

$lang->user->personalData['createdTodos']        = 'Todos Created';
$lang->user->personalData['createdRequirements'] = "Requirements Created";
$lang->user->personalData['createdStories']      = "Stories Created";
$lang->user->personalData['finishedTasks']       = 'Tasks Finished';
$lang->user->personalData['createdBugs']         = 'Bugs Created';
$lang->user->personalData['resolvedBugs']        = 'Bugs Resolved';
$lang->user->personalData['createdCases']        = 'Cases Created';
$lang->user->personalData['createdRisks']        = 'Risks Created';
$lang->user->personalData['resolvedRisks']       = 'Risks Resolved';
$lang->user->personalData['createdIssues']       = 'Issues Created';
$lang->user->personalData['resolvedIssues']      = 'Issues Resolved';
$lang->user->personalData['createdDocs']         = 'Docs Created';

$lang->user->keepLogin['on']   = 'Duy trì đăng nhập';
$lang->user->loginWithDemoUser = 'Đăng nhập Demo:';

$lang->user->tpl = new stdclass();
$lang->user->tpl->type    = 'Loại';
$lang->user->tpl->title   = 'TPL Title';
$lang->user->tpl->content = 'Nội dung';
$lang->user->tpl->public  = 'Công khai';

$lang->usertpl = new stdclass();
$lang->usertpl->title = 'Tên mẫu';

$lang->user->placeholder = new stdclass();
$lang->user->placeholder->account   = '>= 3 chữ, gạch chân và số';
$lang->user->placeholder->password1 = '>= 6 chữ';
$lang->user->placeholder->role      = "Vai trò được liên kết đến nội dung và thứ tự danh sách người dùng.";
$lang->user->placeholder->group     = "Nhóm được liên kết tới phân quyền người dùng.";
$lang->user->placeholder->commiter  = 'Tài khoản SVN/Git';
$lang->user->placeholder->verify    = 'Vui lòng nhập mật khẩu đăng nhập của bạn.';

$lang->user->placeholder->passwordStrength[1] = '>= 6 chữ và số';
$lang->user->placeholder->passwordStrength[2] = '>= 10 chữ, sood và ký tự đặc biệt';

$lang->user->error = new stdclass();
$lang->user->error->account        = "ID %s，tài khoản phải >= 3 chữ, gạch chân hoặc số";
$lang->user->error->accountDupl    = "ID %s，tài khoản được sử dụng.";
$lang->user->error->realname       = "ID %s，phải là tên thật";
$lang->user->error->password       = "ID %s，mật khẩu phải >= 6 ký tự.";
$lang->user->error->mail           = "ID %s，vui lòng nhập địa chỉ Email hợp lệ";
$lang->user->error->reserved       = "ID %s，tài khoản được bảo mật.";
$lang->user->error->weakPassword   = "ID %s，độ mạnh mật khẩu này yếu hơn thiết lập hệ thống.";
$lang->user->error->dangerPassword = "ID %s，Mật khẩu không thể được dùng với [%s] những điều chung này được dùng nếu mật khẩu..";

$lang->user->error->verifyPassword   = "Xác thực thất bại. Vui lòng nhập mạt khẩu đăng nhập của bạn.";
$lang->user->error->originalPassword = "Old password is incorrect.";
$lang->user->error->noAccess         = "This user is not from your department. You have no access to this user information.";

$lang->user->contactFieldList['phone']    = $lang->user->phone;
$lang->user->contactFieldList['mobile']   = $lang->user->mobile;
$lang->user->contactFieldList['qq']       = $lang->user->qq;
$lang->user->contactFieldList['dingding'] = $lang->user->dingding;
$lang->user->contactFieldList['weixin']   = $lang->user->weixin;
$lang->user->contactFieldList['skype']    = $lang->user->skype;
$lang->user->contactFieldList['slack']    = $lang->user->slack;
$lang->user->contactFieldList['whatsapp'] = $lang->user->whatsapp;

$lang->user->executionTypeList['stage']  = 'Stage';
$lang->user->executionTypeList['sprint'] = $lang->iterationCommon;

$lang->user->contacts = new stdclass();
$lang->user->contacts->common   = 'Liên lạc';
$lang->user->contacts->listName = 'Tên danh sách';
$lang->user->contacts->userList = 'Danh sách người dùng';

$lang->user->contacts->manage        = 'Quản lý danh sách';
$lang->user->contacts->contactsList  = 'Liên hệ danh sách';
$lang->user->contacts->selectedUsers = 'Người dùng';
$lang->user->contacts->selectList    = 'Danh sách';
$lang->user->contacts->createList    = 'Tạo danh sách';
$lang->user->contacts->noListYet     = 'Không có danh sách liên hệ tồn tại. Vui lòng tạo một trước.';
$lang->user->contacts->confirmDelete = 'Bạn có muốn xóa danh sách này?';
$lang->user->contacts->or            = ' or ';

$lang->user->resetFail       = "Thất bại. Vui lòng kiểm tra tài khoản.";
$lang->user->resetSuccess    = "Reset! Vui lòng sử dụng mật khẩu mới của bạn để đăng nhập.";
$lang->user->noticeResetFile = "<h5>Liên hệ quản trị viên để thiết lập lại mật khẩu của bạn.</h5>
 <h5>Nếu là bạn, vui lòng đăng nhập host ZenTao của bạn và tạo một tập tin tên  <span> '%s' </span>.</h5>
 <p>Chú ý:</p>
 <ol>
 <li>Giữ tập tin này rỗng.</li>
 <li>Nếu tập tin đã tồn tại, xóa và tạo lại.</li>
 </ol>";
$lang->user->notice4Safe = "Warning: Weak password of one click package detected";
$lang->user->process4DIR = "It is detected that you may be using the one click installation package environment. Other sites in the environment are still using simple passwords. For security reasons, if you do not use other sites, please handle them in time. Delete or rename the %s directory. Visit: <a href='https://www.zentao.pm/book/zentaomanual/fix-weak-password-564.html' target='_blank'>https://www.zentao.pm/book/zentaomanual/fix-weak-password-564.html</a>";
$lang->user->process4DB  = "It is detected that you may be using the one click installation package environment. Other sites in the environment are still using simple passwords. For security reasons, if you do not use other sites, please handle them in time. Please login database and modify password field of zt_user table of %s database. Visit: <a href='https://www.zentao.pm/book/zentaomanual/fix-weak-password-564.html' target='_blank'>https://www.zentao.pm/book/zentaomanual/fix-weak-password-564.html</a>";
$lang->user->mkdirWin = <<<EOT
    <html><head><meta charset='utf-8'></head>
    <body><table align='center' style='width:700px; margin-top:100px; border:1px solid gray; font-size:14px;'><tr><td style='padding:8px'>
    <div style='margin-bottom:8px;'>不能创建临时目录，请确认目录<strong style='color:#ed980f'>%s</strong>是否存在并有操作权限。</div> 
    <div>Can't create tmp directory, make sure the directory <strong style='color:#ed980f'>%s</strong> exists and has permission to operate.</div>
    </td></tr></table></body></html>
EOT;
$lang->user->mkdirLinux = <<<EOT
    <html><head><meta charset='utf-8'></head>
    <body><table align='center' style='width:700px; margin-top:100px; border:1px solid gray; font-size:14px;'><tr><td style='padding:8px'>
    <div style='margin-bottom:8px;'>不能创建临时目录，请确认目录<strong style='color:#ed980f'>%s</strong>是否存在并有操作权限。</div>  
    <div style='margin-bottom:8px;'>命令为：<strong style='color:#ed980f'>chmod o=rwx -R %s</strong>。</div>
    <div>Can't create tmp directory, make sure the directory <strong style='color:#ed980f'>%s</strong> exists and has permission to operate.</div>
    <div style='margin-bottom:8px;'>Commond: <strong style='color:#ed980f'>chmod o=rwx -R %s</strong>.</div>
    </td></tr></table></body></html>
EOT;
